# Python Paraguay community package

A simple 'easter egg' package for the PythonPy community inspired in Python's `antigravity` module.


### Installing

```
pip install paraguay
```

End with an example of getting some data out of the system or using it for a little demo

### How to use

```
from paraguay import community
```
Opens Python Paraguay website

```
from paraguay import meetup
```
Opens Python Paraguay Meetup Group

```
from paraguay import telegram
```
Opens Python Paraguay Telegram Group

## TODO

- `import this` module with the Zen of Python in guaraní

## Contributing

1. Fork it!
2. Create your feature branch: `git checkout -b my-new-feature`
3. Commit your changes: `git commit -am 'Add some feature'`
4. Push to the branch: `git push origin my-new-feature`
5. Submit a pull request :D

## Authors

* **Marcelo Elizeche Landó** - *Initial work* - [melizeche](https://github.com/melizeche)

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
